@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+import argparse
 import os
 import sys
 
@@ -11,6 +12,11 @@ MAPPING, MAPPINGREMOTE, MAPPINGBULK = (
     'mapping', 'mapping-remote', 'mapping-bulk'
 )
 
+def check_file_exists(file=None):
+    if file and not os.path.isfile(file):
+        raise argparse.ArgumentTypeError(
+            'certificate file %s not found' % file)
+
 
 def tx_main_parser():
     description = "This is the Transifex command line client which"\
@@ -46,6 +52,12 @@ def tx_main_parser():
         default=(os.name == 'nt' or not sys.stdout.isatty()),
         help="disable colors in the output of commands"
     )
+    # set a private CA cert bundle file to override the system one
+    parser.add_argument(
+        "--cacert", action="store", dest="cacert", default=None,
+        help="set path to CA certificate bundle file",
+        metavar='/path/to/ca-cert-bundle-file', type=check_file_exists
+    )
     parser.add_argument(
         "command", action="store", help="TX command", nargs='?', default=None
     )
@@ -182,6 +194,11 @@ def pull_parser():
     parser.add_argument("--pseudo", action="store_true", dest="pseudo",
                         default=False, help="Apply this option to download "
                         "a pseudo file.")
+    parser.add_argument("--use-git-timestamps", action="store_true",
+                        dest="use_git_timestamps", default=False,
+                        help="Compare local files to their Transifex version "
+                        "by their latest commit timestamps. Use this option, "
+                        "for example, when cloning a Git repository.")
     parser.add_argument(
         "--mode", action="store", dest="mode", help=(
             "Specify the mode of the translation file to pull (e.g. "
@@ -244,6 +261,11 @@ def push_parser():
     parser.add_argument("-x", "--xliff", action="store_true", dest="xliff",
                         default=False, help="Apply this option to upload "
                         "file as xliff.")
+    parser.add_argument("--use-git-timestamps", action="store_true",
+                        dest="use_git_timestamps", default=False,
+                        help="Compare local files to their Transifex version "
+                        "by their latest commit timestamps. Use this option, "
+                        "for example, when cloning a Git repository.")
     parser.add_argument(
         "-b", "--branch", action="store", dest="branch",
         default=None, nargs="?", const='-1',
